@@ -1,3 +1,4 @@
+import functools
 import json
 import os
 import time
@@ -6,7 +7,6 @@ import luigi
 
 from servicecatalog_puppet import aws
 from servicecatalog_puppet import config
-from servicecatalog_puppet import manifest_utils_for_launches
 from servicecatalog_puppet import constants
 from servicecatalog_puppet.workflow import (
     tasks,
@@ -29,22 +29,51 @@ class LaunchSectionTask(manifest_tasks.SectionTask):
         requirements = list()
 
         for name, details in self.manifest.get(constants.LAUNCHES, {}).items():
-            requirements += self.handle_requirements_for(
-                name,
-                details,
-                constants.LAUNCH,
-                constants.LAUNCHES,
-                self.execution_mode == constants.EXECUTION_MODE_SPOKE,
-                LaunchForRegionTask,
-                LaunchForAccountTask,
-                LaunchForAccountAndRegionTask,
-                LaunchTask,
-                dict(
-                    launch_name=name,
-                    puppet_account_id=self.puppet_account_id,
-                    manifest_file_path=self.manifest_file_path,
-                ),
-            )
+            execution = details.get("execution")
+
+            if self.is_running_in_spoke():
+                if execution == constants.EXECUTION_MODE_SPOKE:
+                    requirements += self.handle_requirements_for(
+                        name,
+                        constants.LAUNCH,
+                        constants.LAUNCHES,
+                        LaunchForRegionTask,
+                        LaunchForAccountTask,
+                        LaunchForAccountAndRegionTask,
+                        LaunchTask,
+                        dict(
+                            launch_name=name,
+                            puppet_account_id=self.puppet_account_id,
+                            manifest_file_path=self.manifest_file_path,
+                        ),
+                    )
+                else:
+                    continue
+
+            else:
+                if execution != constants.EXECUTION_MODE_SPOKE:
+                    requirements += self.handle_requirements_for(
+                        name,
+                        constants.LAUNCH,
+                        constants.LAUNCHES,
+                        LaunchForRegionTask,
+                        LaunchForAccountTask,
+                        LaunchForAccountAndRegionTask,
+                        LaunchTask,
+                        dict(
+                            launch_name=name,
+                            puppet_account_id=self.puppet_account_id,
+                            manifest_file_path=self.manifest_file_path,
+                        ),
+                    )
+                else:
+                    requirements.append(
+                        LaunchForSpokeExecutionTask(
+                            launch_name=name,
+                            puppet_account_id=self.puppet_account_id,
+                            manifest_file_path=self.manifest_file_path,
+                        )
+                    )
 
         return requirements
 
@@ -228,9 +257,7 @@ class DoDescribeProvisioningParameters(ProvisioningTask):
             )
 
 
-class ProvisionProductTask(
-    ProvisioningTask, manifest_tasks.ManifestMixen, dependency.DependenciesMixin
-):
+class ProvisionProductTask(ProvisioningTask, dependency.DependenciesMixin):
     launch_name = luigi.Parameter()
     puppet_account_id = luigi.Parameter()
 
@@ -1025,7 +1052,7 @@ class RunDeployInSpokeTask(tasks.PuppetTask):
         self.write_output(dict(account_id=self.account_id, **response))
 
 
-class LaunchInSpokeTask(ProvisioningTask, manifest_tasks.ManifestMixen):
+class LaunchForSpokeExecutionTask(ProvisioningTask, dependency.DependenciesMixin):
     launch_name = luigi.Parameter()
     puppet_account_id = luigi.Parameter()
 
@@ -1036,85 +1063,115 @@ class LaunchInSpokeTask(ProvisioningTask, manifest_tasks.ManifestMixen):
             "cache_invalidator": self.cache_invalidator,
         }
 
-    def generate_tasks(self, task_defs, manifest):
-        self.info("generate_provisions")
-        provisions = []
-
-        for task_def in task_defs:
-            if self.single_account == "None":
-                pass
-            else:
-                if task_def.get("account_id") != self.single_account:
-                    continue
-            task_status = task_def.get("status")
-            del task_def["status"]
-            del task_def["depends_on"]
-            run_deploy_in_spoke_task_params = dict(
-                manifest_file_path=self.manifest_file_path,
-                puppet_account_id=self.puppet_account_id,
-                account_id=task_def.get("account_id"),
-                home_region=config.get_home_region(self.puppet_account_id),
-                regions=config.get_regions(self.puppet_account_id),
-                should_collect_cloudformation_events=self.should_use_sns,
-                should_forward_events_to_eventbridge=config.get_should_use_eventbridge(
-                    self.puppet_account_id
-                ),
-                should_forward_failures_to_opscenter=config.get_should_forward_failures_to_opscenter(
-                    self.puppet_account_id
-                ),
-            )
-
-            if task_status == constants.PROVISIONED:
-                provisioning_parameters = {}
-                for p in ProvisionProductTask.get_param_names(include_significant=True):
-                    provisioning_parameters[p] = task_def.get(p)
-
-                if self.is_dry_run:
-                    provisions.append(
-                        ProvisionProductDryRunTask(**provisioning_parameters)
-                    )
-                else:
-                    provisions.append(
-                        RunDeployInSpokeTask(**run_deploy_in_spoke_task_params)
-                    )
-
-            elif task_status == constants.TERMINATED:
-                terminating_parameters = {}
-                for p in TerminateProductTask.get_param_names(include_significant=True):
-                    terminating_parameters[p] = task_def.get(p)
-
-                if self.is_dry_run:
-                    provisions.append(
-                        TerminateProductDryRunTask(**terminating_parameters)
-                    )
-                else:
-                    provisions.append(
-                        RunDeployInSpokeTask(**run_deploy_in_spoke_task_params)
-                    )
-            else:
-                raise Exception(f"Unsupported status of {task_status}")
-        self.info(f"len of provisions: {len(provisions)}")
-        return provisions
-
     def requires(self):
-        requirements = dict()
-        configuration = manifest_utils_for_launches.get_configuration_from_launch(
-            self.manifest, self.launch_name
-        )
-        configuration["puppet_account_id"] = self.puppet_account_id
+        from servicecatalog_puppet.workflow import codebuild_runs
+        from servicecatalog_puppet.workflow import spoke_local_portfolios
+        from servicecatalog_puppet.workflow import assertions
+        from servicecatalog_puppet.workflow import lambda_invocations
 
-        launch_tasks_def = self.manifest.get_task_defs_from_details(
-            self.puppet_account_id, False, self.launch_name, configuration, "launches"
+        these_dependencies = list()
+        common_args = dict(
+            manifest_file_path=self.manifest_file_path,
+            puppet_account_id=self.puppet_account_id,
         )
-        requirements["launches"] = self.generate_tasks(launch_tasks_def, self.manifest)
-        return requirements
+        dependencies = self.manifest.get_launch(self.launch_name).get("depends_on", [])
+        for depends_on in dependencies:
+            depends_on_affinity = depends_on.get(constants.AFFINITY)
+            depends_on_type = depends_on.get("type")
+            if depends_on_type == constants.LAUNCH:
+                if depends_on_affinity == constants.LAUNCH:
+                    dep = self.manifest.get_launch(depends_on.get("name"))
+                    if dep.get("execution") == constants.EXECUTION_MODE_SPOKE:
+                        these_dependencies.append(
+                            LaunchForSpokeExecutionTask(
+                                **common_args, launch_name=depends_on.get("name"),
+                            )
+                        )
+                    else:
+                        these_dependencies.append(
+                            LaunchTask(
+                                **common_args, launch_name=depends_on.get("name"),
+                            )
+                        )
+                else:
+                    raise Exception(
+                        "Could can only depend on a launch using affinity launch when using spoke execution mode"
+                    )
+
+            elif depends_on_type == constants.SPOKE_LOCAL_PORTFOLIO:
+                if depends_on_affinity == constants.SPOKE_LOCAL_PORTFOLIO:
+                    these_dependencies.append(
+                        spoke_local_portfolios.SpokeLocalPortfolioTask(
+                            **common_args,
+                            spoke_local_portfolio_name=depends_on.get("name"),
+                        )
+                    )
+                else:
+                    raise Exception(
+                        "Could can only depend on a spoke_local_portfolio using affinity spoke_local_portfolios when using spoke execution mode"
+                    )
+
+            elif depends_on_type == constants.ASSERTION:
+                if depends_on_affinity == constants.ASSERTION:
+                    these_dependencies.append(
+                        assertions.AssertionTask(
+                            **common_args, assertion_name=depends_on.get("name"),
+                        )
+                    )
+                else:
+                    raise Exception(
+                        "Could can only depend on an assertion using affinity assertion when using spoke execution mode"
+                    )
+
+            elif depends_on_type == constants.CODE_BUILD_RUN:
+                if depends_on_affinity == constants.CODE_BUILD_RUN:
+                    these_dependencies.append(
+                        codebuild_runs.CodeBuildRunTask(
+                            **common_args, code_build_run_name=depends_on.get("name"),
+                        )
+                    )
+                else:
+                    raise Exception(
+                        "Could can only depend on a code_build_run using affinity code_build_run when using spoke execution mode"
+                    )
+
+            elif depends_on_type == constants.LAMBDA_INVOCATION:
+                if depends_on_affinity == constants.LAMBDA_INVOCATION:
+                    these_dependencies.append(
+                        lambda_invocations.LambdaInvocationTask(
+                            **common_args,
+                            lambda_invocation_name=depends_on.get("name"),
+                        )
+                    )
+                else:
+                    raise Exception(
+                        "Could can only depend on a lambda_invocation using affinity lambda_invocation when using spoke execution mode"
+                    )
+
+        return these_dependencies
+
+    @functools.lru_cache(maxsize=8)
+    def get_tasks(self):
+        tasks_to_run = list()
+        for account_id in self.manifest.get_account_ids_used_for_section_item(
+            self.puppet_account_id, self.section_name, self.launch_name
+        ):
+            tasks_to_run.append(
+                RunDeployInSpokeTask(
+                    manifest_file_path=self.manifest_file_path,
+                    puppet_account_id=self.puppet_account_id,
+                    account_id=account_id,
+                )
+            )
+        return tasks_to_run
 
     def run(self):
-        self.info("started")
+        tasks_to_run = self.get_tasks()
+        yield tasks_to_run
         self.write_output(self.params_for_results_display())
 
 
-class LaunchForTask(ProvisioningTask, manifest_tasks.ManifestMixen):
+class LaunchForTask(ProvisioningTask):
     launch_name = luigi.Parameter()
     puppet_account_id = luigi.Parameter()
 
