@@ -110,6 +110,9 @@ class GetVersionIdByVersionName(PortfolioManagementTask, manifest_tasks.Manifest
     account_id = luigi.Parameter()
     region = luigi.Parameter()
 
+    product_id = None
+    version_id = None
+
     def params_for_results_display(self):
         return {
             "puppet_account_id": self.puppet_account_id,
@@ -128,26 +131,36 @@ class GetVersionIdByVersionName(PortfolioManagementTask, manifest_tasks.Manifest
 
     def requires(self):
         if self.manifest.has_cache():
-            return []
-        else:
-            return dict(
-                product=GetProductIdByProductName(
-                    manifest_file_path=self.manifest_file_path,
-                    puppet_account_id=self.puppet_account_id,
-                    portfolio=self.portfolio,
-                    product=self.product,
-                    account_id=self.account_id,
-                    region=self.region,
-                )
+            if (
+                self.manifest.get("id_cache")
+                .get(self.region, {})
+                .get(self.portfolio, {})
+                .get("products", {})
+                .get(self.product, {})
+            ):
+                product = self.manifest["id_cache"][self.region][self.portfolio][
+                    "products"
+                ][self.product]
+                if product.get("versions", {}).get(self.version):
+                    self.product_id = product["id"]
+                    self.version_id = product["versions"][self.version]
+                    return []
+
+        return dict(
+            product=GetProductIdByProductName(
+                manifest_file_path=self.manifest_file_path,
+                puppet_account_id=self.puppet_account_id,
+                portfolio=self.portfolio,
+                product=self.product,
+                account_id=self.account_id,
+                region=self.region,
             )
+        )
 
     def run(self):
-        if self.manifest.has_cache():
-            product = self.manifest["id_cache"][self.region][self.portfolio][
-                "products"
-            ][self.product]
-            product_id = product["id"]
-            version_id = product["versions"][self.version]
+        if self.product_id is not None:
+            product_id = self.product_id
+            version_id = self.version_id
         else:
             details = self.load_from_input("product")
             product_id = details.get("product_id")
@@ -1834,38 +1847,40 @@ class GenerateManifestWithIdsTask(tasks.PuppetTask, manifest_tasks.ManifestMixen
         regions = config.get_regions(self.puppet_account_id)
         global_id_cache = dict()
         new_manifest["id_cache"] = global_id_cache
+
         for region in regions:
-            id_cache = dict()
-            global_id_cache[region] = id_cache
+            regional_id_cache = dict()
             r = self.input().get(region)
             for launch_name, launch_details in self.manifest.get_launches_items():
                 target = r.get(launch_details.get("portfolio")).get("details")
                 portfolio_id = json.loads(target.open("r").read()).get("portfolio_id")
                 portfolio_name = launch_details.get("portfolio")
-                if id_cache.get(portfolio_name) is None:
-                    id_cache[portfolio_name] = dict(id=portfolio_id, products=dict())
+                if regional_id_cache.get(portfolio_name) is None:
+                    regional_id_cache[portfolio_name] = dict(
+                        id=portfolio_id, products=dict()
+                    )
 
                 product = launch_details.get("product")
                 target = (
                     r.get(launch_details.get("portfolio")).get("products").get(product)
                 )
                 all_details = json.loads(target.open("r").read())
-                for p in all_details:
-                    if p.get("Name") == product:
+                all_products_and_their_versions = all_details
+                for p in all_products_and_their_versions:
+                    if (
+                        regional_id_cache[portfolio_name]["products"].get(p.get("Name"))
+                        is None
+                    ):
+                        regional_id_cache[portfolio_name]["products"][
+                            p.get("Name")
+                        ] = dict(id=p.get("ProductId"), versions=dict())
 
-                        if (
-                            id_cache[portfolio_name].get("products").get(product)
-                            is None
-                        ):
-                            id_cache[portfolio_name]["products"][product] = dict(
-                                id=p.get("ProductId"), versions=dict()
-                            )
-                        version = launch_details.get("version")
-                        for a in p.get("provisioning_artifact_details"):
-                            if a.get("Name") == version:
-                                id_cache[portfolio_name]["products"][product][
-                                    "versions"
-                                ][version] = a.get("Id")
+                    for a in p.get("provisioning_artifact_details"):
+                        regional_id_cache[portfolio_name]["products"][p.get("Name")][
+                            "versions"
+                        ][a.get("Name")] = a.get("Id")
+
+            global_id_cache[region] = regional_id_cache
 
         self.write_output(
             yaml.safe_dump(json.loads(json.dumps(new_manifest))), skip_json_dump=True
